Procedural macro for the arguments! { ... }
macro-argument parser for seam macros.
TODO: Convert all panic!(..) calls to actual compiler errors.
Macros
- arguments
- Macro that generates an argument parser and builds a custom struct holding provided arguments, given a schema and the list of arguments.